@@ -1,13 +1,13 @@
 ;;; magit-annex.el --- Control git-annex from Magit  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2013-2017 Kyle Meyer <kyle@kyleam.com>
+;; Copyright (C) 2013-2018 Kyle Meyer <kyle@kyleam.com>
 
 ;; Author: Kyle Meyer <kyle@kyleam.com>
 ;;         Rémi Vanicat <vanicat@debian.org>
 ;; URL: https://github.com/magit/magit-annex
 ;; Keywords: vc tools
-;; Version: 1.4.0
-;; Package-Requires: ((cl-lib "0.3") (magit "2.11.0"))
+;; Version: 1.5.0
+;; Package-Requires: ((cl-lib "0.3") (magit "2.12.0"))
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -297,14 +297,14 @@ With a prefix argument, prompt for FILE.
       (pcase (list (magit-diff-type) (magit-diff-scope))
         (`(untracked file)
          (magit-annex-run "add" (directory-file-name
-                                 (magit-section-value it))))
+                                 (oref it value))))
         (`(untracked files)
          (magit-annex-run "add" (mapcar #'directory-file-name
                                         (magit-region-values))))
         (`(untracked list)
          (magit-annex-run "add" (magit-untracked-files)))
         (`(unstaged file)
-         (magit-annex-run "add" (magit-section-value it)))
+         (magit-annex-run "add" (oref it value)))
         (`(unstaged files)
          (magit-annex-run "add" (magit-region-values)))
         (`(unstaged list)
@@ -439,7 +439,7 @@ With a prefix argument, prompt for FILE.
   (magit-section-case
     (unused-data
      (let ((data-nums (or (mapcar #'car (magit-region-values))
-                          (list (car (magit-section-value it))))))
+                          (list (car (oref it value))))))
        (magit-annex-run "addunused" data-nums)))))
 
 (defun magit-annex-unused-drop (&optional force)
@@ -450,7 +450,7 @@ With prefix argument FORCE, pass \"--force\" flag to
   (magit-section-case
     (unused-data
      (let ((data-nums (or (mapcar #'car (magit-region-values))
-                          (list (car (magit-section-value it))))))
+                          (list (car (oref it value))))))
        (magit-annex-run "dropunused" (if force
                                          (cons "--force" data-nums)
                                        data-nums))))
@@ -470,10 +470,10 @@ value for the '-S' flag.  The '--stat' flag is also enabled if
 \('git log [--stat] -S<KEY>')"
   (interactive)
   (let ((section (magit-current-section)))
-    (if (not (eq (magit-section-type section) 'unused-data))
+    (if (not (eq (oref section type) 'unused-data))
         (call-interactively #'magit-log-popup)
       (let ((magit-log-arguments
-             `(,(concat "-S" (cdr (magit-section-value section)))
+             `(,(concat "-S" (cdr (oref section value)))
                ,(and magit-annex-unused-stat-argument "--stat")
                ,@(cl-remove-if
                   (lambda (x) (string-prefix-p "-S" x))
@@ -500,7 +500,7 @@ the file within Emacs."
   (interactive "P")
   (magit-section-case
     (unused-data
-     (let* ((key (cdr (magit-section-value it)))
+     (let* ((key (cdr (oref it value)))
             (file (magit-annex--file-name-from-key key)))
        (cond
         (in-emacs
@@ -586,7 +586,7 @@ Type \\[magit-annex-unused-open] to open the file.
     (let ((num (match-string 1))
           (key (match-string 2)))
       (delete-region (match-beginning 0) (match-end 0))
-      (magit-insert-section it (unused-data (cons num key))
+      (magit-insert-section (unused-data (cons num key))
         (insert (format "   %-3s   %s" num key))
         (forward-line)))))
 
@@ -675,7 +675,7 @@ on the file at point.
     (let ((locs (match-string 1))
           (file (match-string 2)))
       (delete-region (match-beginning 0) (match-end 0))
-      (magit-insert-section it (annex-list-file (cons locs file))
+      (magit-insert-section (annex-list-file (cons locs file))
         (insert (format "%s %s" locs file))
         (forward-line)))))
 
